# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RuleEcsArgs', 'RuleEcs']

@pulumi.input_type
class RuleEcsArgs:
    def __init__(__self__, *,
                 cloud_connector_id: pulumi.Input[_builtins.str],
                 container: Optional[pulumi.Input['RuleEcsContainerArgs']] = None,
                 custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 https: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RuleEcs resource.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_domains: Custom URLs used to access the instances
        :param pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]] https: Http routing configuration
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        """
        pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if container is not None:
            pulumi.set(__self__, "container", container)
        if custom_domains is not None:
            pulumi.set(__self__, "custom_domains", custom_domains)
        if depends is not None:
            pulumi.set(__self__, "depends", depends)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if https is not None:
            pulumi.set(__self__, "https", https)
        if idle_time_mins is not None:
            pulumi.set(__self__, "idle_time_mins", idle_time_mins)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> pulumi.Input[_builtins.str]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @cloud_connector_id.setter
    def cloud_connector_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud_connector_id", value)

    @_builtins.property
    @pulumi.getter
    def container(self) -> Optional[pulumi.Input['RuleEcsContainerArgs']]:
        return pulumi.get(self, "container")

    @container.setter
    def container(self, value: Optional[pulumi.Input['RuleEcsContainerArgs']]):
        pulumi.set(self, "container", value)

    @_builtins.property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Custom URLs used to access the instances
        """
        return pulumi.get(self, "custom_domains")

    @custom_domains.setter
    def custom_domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "custom_domains", value)

    @_builtins.property
    @pulumi.getter
    def depends(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]]]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @depends.setter
    def depends(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]]]):
        pulumi.set(self, "depends", value)

    @_builtins.property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @_builtins.property
    @pulumi.getter
    def https(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]]]:
        """
        Http routing configuration
        """
        return pulumi.get(self, "https")

    @https.setter
    def https(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]]]):
        pulumi.set(self, "https", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @idle_time_mins.setter
    def idle_time_mins(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "idle_time_mins", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _RuleEcsState:
    def __init__(__self__, *,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 container: Optional[pulumi.Input['RuleEcsContainerArgs']] = None,
                 custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 https: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.float]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RuleEcs resources.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_domains: Custom URLs used to access the instances
        :param pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]] https: Http routing configuration
        :param pulumi.Input[_builtins.float] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        """
        if cloud_connector_id is not None:
            pulumi.set(__self__, "cloud_connector_id", cloud_connector_id)
        if container is not None:
            pulumi.set(__self__, "container", container)
        if custom_domains is not None:
            pulumi.set(__self__, "custom_domains", custom_domains)
        if depends is not None:
            pulumi.set(__self__, "depends", depends)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if https is not None:
            pulumi.set(__self__, "https", https)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if idle_time_mins is not None:
            pulumi.set(__self__, "idle_time_mins", idle_time_mins)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @cloud_connector_id.setter
    def cloud_connector_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud_connector_id", value)

    @_builtins.property
    @pulumi.getter
    def container(self) -> Optional[pulumi.Input['RuleEcsContainerArgs']]:
        return pulumi.get(self, "container")

    @container.setter
    def container(self, value: Optional[pulumi.Input['RuleEcsContainerArgs']]):
        pulumi.set(self, "container", value)

    @_builtins.property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Custom URLs used to access the instances
        """
        return pulumi.get(self, "custom_domains")

    @custom_domains.setter
    def custom_domains(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "custom_domains", value)

    @_builtins.property
    @pulumi.getter
    def depends(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]]]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @depends.setter
    def depends(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsDependArgs']]]]):
        pulumi.set(self, "depends", value)

    @_builtins.property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "dry_run", value)

    @_builtins.property
    @pulumi.getter
    def https(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]]]:
        """
        Http routing configuration
        """
        return pulumi.get(self, "https")

    @https.setter
    def https(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleEcsHttpArgs']]]]):
        pulumi.set(self, "https", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @idle_time_mins.setter
    def idle_time_mins(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "idle_time_mins", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("harness:autostopping/ruleEcs:RuleEcs")
class RuleEcs(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 container: Optional[pulumi.Input[Union['RuleEcsContainerArgs', 'RuleEcsContainerArgsDict']]] = None,
                 custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsDependArgs', 'RuleEcsDependArgsDict']]]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 https: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsHttpArgs', 'RuleEcsHttpArgsDict']]]]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a AutoStopping rule for ECS services.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.autostopping.RuleEcs("test",
            name="name",
            cloud_connector_id="cloud_connector_id",
            idle_time_mins=10,
            dry_run=True,
            container={
                "cluster": "cluster",
                "service": "service",
                "region": "us-east-1",
                "task_count": 1,
            },
            tcp=[{
                "proxyId": "proxy_id",
                "forwardRule": [{
                    "port": 2233,
                }],
            }],
            depends=[{
                "rule_id": 24576,
                "delay_in_sec": 5,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_domains: Custom URLs used to access the instances
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsDependArgs', 'RuleEcsDependArgsDict']]]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsHttpArgs', 'RuleEcsHttpArgsDict']]]] https: Http routing configuration
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleEcsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a AutoStopping rule for ECS services.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.autostopping.RuleEcs("test",
            name="name",
            cloud_connector_id="cloud_connector_id",
            idle_time_mins=10,
            dry_run=True,
            container={
                "cluster": "cluster",
                "service": "service",
                "region": "us-east-1",
                "task_count": 1,
            },
            tcp=[{
                "proxyId": "proxy_id",
                "forwardRule": [{
                    "port": 2233,
                }],
            }],
            depends=[{
                "rule_id": 24576,
                "delay_in_sec": 5,
            }])
        ```

        :param str resource_name: The name of the resource.
        :param RuleEcsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleEcsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 container: Optional[pulumi.Input[Union['RuleEcsContainerArgs', 'RuleEcsContainerArgsDict']]] = None,
                 custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 depends: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsDependArgs', 'RuleEcsDependArgsDict']]]]] = None,
                 dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
                 https: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsHttpArgs', 'RuleEcsHttpArgsDict']]]]] = None,
                 idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleEcsArgs.__new__(RuleEcsArgs)

            if cloud_connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'cloud_connector_id'")
            __props__.__dict__["cloud_connector_id"] = cloud_connector_id
            __props__.__dict__["container"] = container
            __props__.__dict__["custom_domains"] = custom_domains
            __props__.__dict__["depends"] = depends
            __props__.__dict__["dry_run"] = dry_run
            __props__.__dict__["https"] = https
            __props__.__dict__["idle_time_mins"] = idle_time_mins
            __props__.__dict__["name"] = name
            __props__.__dict__["identifier"] = None
        super(RuleEcs, __self__).__init__(
            'harness:autostopping/ruleEcs:RuleEcs',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud_connector_id: Optional[pulumi.Input[_builtins.str]] = None,
            container: Optional[pulumi.Input[Union['RuleEcsContainerArgs', 'RuleEcsContainerArgsDict']]] = None,
            custom_domains: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            depends: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsDependArgs', 'RuleEcsDependArgsDict']]]]] = None,
            dry_run: Optional[pulumi.Input[_builtins.bool]] = None,
            https: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsHttpArgs', 'RuleEcsHttpArgsDict']]]]] = None,
            identifier: Optional[pulumi.Input[_builtins.float]] = None,
            idle_time_mins: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'RuleEcs':
        """
        Get an existing RuleEcs resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud_connector_id: Id of the cloud connector
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_domains: Custom URLs used to access the instances
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsDependArgs', 'RuleEcsDependArgsDict']]]] depends: Dependent rules
        :param pulumi.Input[_builtins.bool] dry_run: Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        :param pulumi.Input[Sequence[pulumi.Input[Union['RuleEcsHttpArgs', 'RuleEcsHttpArgsDict']]]] https: Http routing configuration
        :param pulumi.Input[_builtins.float] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.int] idle_time_mins: Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        :param pulumi.Input[_builtins.str] name: Name of the rule
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleEcsState.__new__(_RuleEcsState)

        __props__.__dict__["cloud_connector_id"] = cloud_connector_id
        __props__.__dict__["container"] = container
        __props__.__dict__["custom_domains"] = custom_domains
        __props__.__dict__["depends"] = depends
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["https"] = https
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["idle_time_mins"] = idle_time_mins
        __props__.__dict__["name"] = name
        return RuleEcs(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="cloudConnectorId")
    def cloud_connector_id(self) -> pulumi.Output[_builtins.str]:
        """
        Id of the cloud connector
        """
        return pulumi.get(self, "cloud_connector_id")

    @_builtins.property
    @pulumi.getter
    def container(self) -> pulumi.Output[Optional['outputs.RuleEcsContainer']]:
        return pulumi.get(self, "container")

    @_builtins.property
    @pulumi.getter(name="customDomains")
    def custom_domains(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Custom URLs used to access the instances
        """
        return pulumi.get(self, "custom_domains")

    @_builtins.property
    @pulumi.getter
    def depends(self) -> pulumi.Output[Optional[Sequence['outputs.RuleEcsDepend']]]:
        """
        Dependent rules
        """
        return pulumi.get(self, "depends")

    @_builtins.property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Boolean that indicates whether the AutoStopping rule should be created in DryRun mode
        """
        return pulumi.get(self, "dry_run")

    @_builtins.property
    @pulumi.getter
    def https(self) -> pulumi.Output[Optional[Sequence['outputs.RuleEcsHttp']]]:
        """
        Http routing configuration
        """
        return pulumi.get(self, "https")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.float]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="idleTimeMins")
    def idle_time_mins(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Idle time in minutes. This is the time that the AutoStopping rule waits before stopping the idle instances.
        """
        return pulumi.get(self, "idle_time_mins")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the rule
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TanzuArgs', 'Tanzu']

@pulumi.input_type
class TanzuArgs:
    def __init__(__self__, *,
                 endpoint: pulumi.Input[_builtins.str],
                 password_secret_name: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 username_secret_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Tanzu resource.
        :param pulumi.Input[_builtins.str] endpoint: The url of the Tanzu platform.
        :param pulumi.Input[_builtins.str] password_secret_name: The name of the Harness secret containing the password to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.bool] skip_validation: Skip validation of Tanzu configuration.
        :param pulumi.Input[_builtins.str] username: The username to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.str] username_secret_name: The name of the Harness secret containing the username to authenticate to Tanzu with.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "password_secret_name", password_secret_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if skip_validation is not None:
            pulumi.set(__self__, "skip_validation", skip_validation)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if username_secret_name is not None:
            pulumi.set(__self__, "username_secret_name", username_secret_name)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Input[_builtins.str]:
        """
        The url of the Tanzu platform.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter(name="passwordSecretName")
    def password_secret_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Harness secret containing the password to use to authenticate to Tanzu.
        """
        return pulumi.get(self, "password_secret_name")

    @password_secret_name.setter
    def password_secret_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "password_secret_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="skipValidation")
    def skip_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Skip validation of Tanzu configuration.
        """
        return pulumi.get(self, "skip_validation")

    @skip_validation.setter
    def skip_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_validation", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username to use to authenticate to Tanzu.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter(name="usernameSecretName")
    def username_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the username to authenticate to Tanzu with.
        """
        return pulumi.get(self, "username_secret_name")

    @username_secret_name.setter
    def username_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username_secret_name", value)


@pulumi.input_type
class _TanzuState:
    def __init__(__self__, *,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 username_secret_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Tanzu resources.
        :param pulumi.Input[_builtins.str] endpoint: The url of the Tanzu platform.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] password_secret_name: The name of the Harness secret containing the password to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.bool] skip_validation: Skip validation of Tanzu configuration.
        :param pulumi.Input[_builtins.str] username: The username to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.str] username_secret_name: The name of the Harness secret containing the username to authenticate to Tanzu with.
        """
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password_secret_name is not None:
            pulumi.set(__self__, "password_secret_name", password_secret_name)
        if skip_validation is not None:
            pulumi.set(__self__, "skip_validation", skip_validation)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if username_secret_name is not None:
            pulumi.set(__self__, "username_secret_name", username_secret_name)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The url of the Tanzu platform.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="passwordSecretName")
    def password_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the password to use to authenticate to Tanzu.
        """
        return pulumi.get(self, "password_secret_name")

    @password_secret_name.setter
    def password_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password_secret_name", value)

    @_builtins.property
    @pulumi.getter(name="skipValidation")
    def skip_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Skip validation of Tanzu configuration.
        """
        return pulumi.get(self, "skip_validation")

    @skip_validation.setter
    def skip_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_validation", value)

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The username to use to authenticate to Tanzu.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username", value)

    @_builtins.property
    @pulumi.getter(name="usernameSecretName")
    def username_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the username to authenticate to Tanzu with.
        """
        return pulumi.get(self, "username_secret_name")

    @username_secret_name.setter
    def username_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "username_secret_name", value)


@pulumi.type_token("harness:cloudprovider/tanzu:Tanzu")
class Tanzu(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 username_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Tanzu cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        tanzu_password = harness.EncryptedText("tanzu_password",
            name="tanzu_password",
            value="<PASSWORD>",
            secret_manager_id=default.id)
        example = harness.cloudprovider.Tanzu("example",
            name="example",
            endpoint="https://endpoint.com",
            skip_validation=True,
            username="<USERNAME>",
            password_secret_name=tanzu_password.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness Tanzu cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/tanzu:Tanzu example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] endpoint: The url of the Tanzu platform.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] password_secret_name: The name of the Harness secret containing the password to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.bool] skip_validation: Skip validation of Tanzu configuration.
        :param pulumi.Input[_builtins.str] username: The username to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.str] username_secret_name: The name of the Harness secret containing the username to authenticate to Tanzu with.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TanzuArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Tanzu cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        tanzu_password = harness.EncryptedText("tanzu_password",
            name="tanzu_password",
            value="<PASSWORD>",
            secret_manager_id=default.id)
        example = harness.cloudprovider.Tanzu("example",
            name="example",
            endpoint="https://endpoint.com",
            skip_validation=True,
            username="<USERNAME>",
            password_secret_name=tanzu_password.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness Tanzu cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/tanzu:Tanzu example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param TanzuArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TanzuArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 username: Optional[pulumi.Input[_builtins.str]] = None,
                 username_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TanzuArgs.__new__(TanzuArgs)

            if endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'endpoint'")
            __props__.__dict__["endpoint"] = endpoint
            __props__.__dict__["name"] = name
            if password_secret_name is None and not opts.urn:
                raise TypeError("Missing required property 'password_secret_name'")
            __props__.__dict__["password_secret_name"] = password_secret_name
            __props__.__dict__["skip_validation"] = skip_validation
            __props__.__dict__["username"] = username
            __props__.__dict__["username_secret_name"] = username_secret_name
        super(Tanzu, __self__).__init__(
            'harness:cloudprovider/tanzu:Tanzu',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            password_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
            skip_validation: Optional[pulumi.Input[_builtins.bool]] = None,
            username: Optional[pulumi.Input[_builtins.str]] = None,
            username_secret_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'Tanzu':
        """
        Get an existing Tanzu resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] endpoint: The url of the Tanzu platform.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] password_secret_name: The name of the Harness secret containing the password to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.bool] skip_validation: Skip validation of Tanzu configuration.
        :param pulumi.Input[_builtins.str] username: The username to use to authenticate to Tanzu.
        :param pulumi.Input[_builtins.str] username_secret_name: The name of the Harness secret containing the username to authenticate to Tanzu with.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TanzuState.__new__(_TanzuState)

        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["name"] = name
        __props__.__dict__["password_secret_name"] = password_secret_name
        __props__.__dict__["skip_validation"] = skip_validation
        __props__.__dict__["username"] = username
        __props__.__dict__["username_secret_name"] = username_secret_name
        return Tanzu(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[_builtins.str]:
        """
        The url of the Tanzu platform.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="passwordSecretName")
    def password_secret_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Harness secret containing the password to use to authenticate to Tanzu.
        """
        return pulumi.get(self, "password_secret_name")

    @_builtins.property
    @pulumi.getter(name="skipValidation")
    def skip_validation(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Skip validation of Tanzu configuration.
        """
        return pulumi.get(self, "skip_validation")

    @_builtins.property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The username to use to authenticate to Tanzu.
        """
        return pulumi.get(self, "username")

    @_builtins.property
    @pulumi.getter(name="usernameSecretName")
    def username_secret_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the Harness secret containing the username to authenticate to Tanzu with.
        """
        return pulumi.get(self, "username_secret_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SpotArgs', 'Spot']

@pulumi.input_type
class SpotArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[_builtins.str],
                 token_secret_name: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Spot resource.
        :param pulumi.Input[_builtins.str] account_id: The Spot account ID
        :param pulumi.Input[_builtins.str] token_secret_name: The name of the Harness secret containing the spot account token
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "token_secret_name", token_secret_name)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[_builtins.str]:
        """
        The Spot account ID
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="tokenSecretName")
    def token_secret_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Harness secret containing the spot account token
        """
        return pulumi.get(self, "token_secret_name")

    @token_secret_name.setter
    def token_secret_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "token_secret_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _SpotState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 token_secret_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Spot resources.
        :param pulumi.Input[_builtins.str] account_id: The Spot account ID
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] token_secret_name: The name of the Harness secret containing the spot account token
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if token_secret_name is not None:
            pulumi.set(__self__, "token_secret_name", token_secret_name)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Spot account ID
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="tokenSecretName")
    def token_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the spot account token
        """
        return pulumi.get(self, "token_secret_name")

    @token_secret_name.setter
    def token_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_secret_name", value)


@pulumi.type_token("harness:cloudprovider/spot:Spot")
class Spot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 token_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Spot cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        spot_token = harness.EncryptedText("spot_token",
            name="spot_token",
            secret_manager_id=default.id,
            value="<SPOT_TOKEN>")
        example = harness.cloudprovider.Spot("example",
            name="example",
            account_id="<SPOT_ACCOUNT_ID>",
            token_secret_name=spot_token.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness Spot cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/spot:Spot example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The Spot account ID
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] token_secret_name: The name of the Harness secret containing the spot account token
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SpotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Spot cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        spot_token = harness.EncryptedText("spot_token",
            name="spot_token",
            secret_manager_id=default.id,
            value="<SPOT_TOKEN>")
        example = harness.cloudprovider.Spot("example",
            name="example",
            account_id="<SPOT_ACCOUNT_ID>",
            token_secret_name=spot_token.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness Spot cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/spot:Spot example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param SpotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SpotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 token_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SpotArgs.__new__(SpotArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["name"] = name
            if token_secret_name is None and not opts.urn:
                raise TypeError("Missing required property 'token_secret_name'")
            __props__.__dict__["token_secret_name"] = token_secret_name
        super(Spot, __self__).__init__(
            'harness:cloudprovider/spot:Spot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            token_secret_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'Spot':
        """
        Get an existing Spot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The Spot account ID
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] token_secret_name: The name of the Harness secret containing the spot account token
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SpotState.__new__(_SpotState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["name"] = name
        __props__.__dict__["token_secret_name"] = token_secret_name
        return Spot(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Spot account ID
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="tokenSecretName")
    def token_secret_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Harness secret containing the spot account token
        """
        return pulumi.get(self, "token_secret_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InfraModuleTestingArgs', 'InfraModuleTesting']

@pulumi.input_type
class InfraModuleTestingArgs:
    def __init__(__self__, *,
                 module_id: pulumi.Input[_builtins.str],
                 org: pulumi.Input[_builtins.str],
                 pipelines: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 project: pulumi.Input[_builtins.str],
                 provider_connector: pulumi.Input[_builtins.str],
                 provisioner_type: pulumi.Input[_builtins.str],
                 provisioner_version: pulumi.Input[_builtins.str],
                 release_pipeline: Optional[pulumi.Input[_builtins.str]] = None,
                 testing_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 testing_metadata: Optional[pulumi.Input['InfraModuleTestingTestingMetadataArgs']] = None,
                 updated: Optional[pulumi.Input[_builtins.int]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a InfraModuleTesting resource.
        :param pulumi.Input[_builtins.str] module_id: Identifier of the module to enable testing for
        :param pulumi.Input[_builtins.str] org: Organization identifier
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] pipelines: List of pipeline IDs to create webhooks for triggering test executions
        :param pulumi.Input[_builtins.str] project: Project identifier
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector for testing purposes
        :param pulumi.Input[_builtins.str] provisioner_version: Provisioner version for testing purposes
        :param pulumi.Input[_builtins.str] release_pipeline: Pipeline ID to create webhooks for releases
        :param pulumi.Input[_builtins.bool] testing_enabled: Whether testing is enabled for the module
        :param pulumi.Input['InfraModuleTestingTestingMetadataArgs'] testing_metadata: Testing metadata for the module
        :param pulumi.Input[_builtins.int] updated: Timestamp when the module was last modified
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: Versions of the module
        """
        pulumi.set(__self__, "module_id", module_id)
        pulumi.set(__self__, "org", org)
        pulumi.set(__self__, "pipelines", pipelines)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "provider_connector", provider_connector)
        pulumi.set(__self__, "provisioner_type", provisioner_type)
        pulumi.set(__self__, "provisioner_version", provisioner_version)
        if release_pipeline is not None:
            pulumi.set(__self__, "release_pipeline", release_pipeline)
        if testing_enabled is not None:
            pulumi.set(__self__, "testing_enabled", testing_enabled)
        if testing_metadata is not None:
            pulumi.set(__self__, "testing_metadata", testing_metadata)
        if updated is not None:
            pulumi.set(__self__, "updated", updated)
        if versions is not None:
            pulumi.set(__self__, "versions", versions)

    @_builtins.property
    @pulumi.getter(name="moduleId")
    def module_id(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the module to enable testing for
        """
        return pulumi.get(self, "module_id")

    @module_id.setter
    def module_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "module_id", value)

    @_builtins.property
    @pulumi.getter
    def org(self) -> pulumi.Input[_builtins.str]:
        """
        Organization identifier
        """
        return pulumi.get(self, "org")

    @org.setter
    def org(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org", value)

    @_builtins.property
    @pulumi.getter
    def pipelines(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        List of pipeline IDs to create webhooks for triggering test executions
        """
        return pulumi.get(self, "pipelines")

    @pipelines.setter
    def pipelines(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "pipelines", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        Project identifier
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> pulumi.Input[_builtins.str]:
        """
        Provider connector for testing purposes
        """
        return pulumi.get(self, "provider_connector")

    @provider_connector.setter
    def provider_connector(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provider_connector", value)

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "provisioner_type")

    @provisioner_type.setter
    def provisioner_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provisioner_type", value)

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> pulumi.Input[_builtins.str]:
        """
        Provisioner version for testing purposes
        """
        return pulumi.get(self, "provisioner_version")

    @provisioner_version.setter
    def provisioner_version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provisioner_version", value)

    @_builtins.property
    @pulumi.getter(name="releasePipeline")
    def release_pipeline(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Pipeline ID to create webhooks for releases
        """
        return pulumi.get(self, "release_pipeline")

    @release_pipeline.setter
    def release_pipeline(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "release_pipeline", value)

    @_builtins.property
    @pulumi.getter(name="testingEnabled")
    def testing_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether testing is enabled for the module
        """
        return pulumi.get(self, "testing_enabled")

    @testing_enabled.setter
    def testing_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "testing_enabled", value)

    @_builtins.property
    @pulumi.getter(name="testingMetadata")
    def testing_metadata(self) -> Optional[pulumi.Input['InfraModuleTestingTestingMetadataArgs']]:
        """
        Testing metadata for the module
        """
        return pulumi.get(self, "testing_metadata")

    @testing_metadata.setter
    def testing_metadata(self, value: Optional[pulumi.Input['InfraModuleTestingTestingMetadataArgs']]):
        pulumi.set(self, "testing_metadata", value)

    @_builtins.property
    @pulumi.getter
    def updated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was last modified
        """
        return pulumi.get(self, "updated")

    @updated.setter
    def updated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated", value)

    @_builtins.property
    @pulumi.getter
    def versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Versions of the module
        """
        return pulumi.get(self, "versions")

    @versions.setter
    def versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "versions", value)


@pulumi.input_type
class _InfraModuleTestingState:
    def __init__(__self__, *,
                 account: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_tag_style: Optional[pulumi.Input[_builtins.str]] = None,
                 module_error: Optional[pulumi.Input[_builtins.str]] = None,
                 module_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 pipelines: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
                 release_pipeline: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 synced: Optional[pulumi.Input[_builtins.int]] = None,
                 system: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[_builtins.str]] = None,
                 testing_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 testing_metadata: Optional[pulumi.Input['InfraModuleTestingTestingMetadataArgs']] = None,
                 updated: Optional[pulumi.Input[_builtins.int]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering InfraModuleTesting resources.
        :param pulumi.Input[_builtins.str] account: Account that owns the module
        :param pulumi.Input[_builtins.int] created: Timestamp when the module was created
        :param pulumi.Input[_builtins.str] description: Description of the module
        :param pulumi.Input[_builtins.str] git_tag_style: Git Tag Style
        :param pulumi.Input[_builtins.str] module_error: Error while retrieving the module
        :param pulumi.Input[_builtins.str] module_id: Identifier of the module to enable testing for
        :param pulumi.Input[_builtins.str] name: Name of the module
        :param pulumi.Input[_builtins.str] org: Organization identifier
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] pipelines: List of pipeline IDs to create webhooks for triggering test executions
        :param pulumi.Input[_builtins.str] project: Project identifier
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector for testing purposes
        :param pulumi.Input[_builtins.str] provisioner_version: Provisioner version for testing purposes
        :param pulumi.Input[_builtins.str] release_pipeline: Pipeline ID to create webhooks for releases
        :param pulumi.Input[_builtins.str] repository: For account connectors, the repository where the module is stored
        :param pulumi.Input[_builtins.str] repository_branch: Repository Branch in which the module should be accessed
        :param pulumi.Input[_builtins.str] repository_commit: Repository Commit in which the module should be accessed
        :param pulumi.Input[_builtins.str] repository_connector: Repository Connector is the reference to the connector for the repository
        :param pulumi.Input[_builtins.str] repository_path: Repository Path is the path in which the module resides
        :param pulumi.Input[_builtins.str] repository_url: URL where the module is stored
        :param pulumi.Input[_builtins.int] synced: Timestamp when the module was last synced
        :param pulumi.Input[_builtins.str] system: Provider of the module
        :param pulumi.Input[_builtins.str] tags: Tags associated with the module
        :param pulumi.Input[_builtins.bool] testing_enabled: Whether testing is enabled for the module
        :param pulumi.Input['InfraModuleTestingTestingMetadataArgs'] testing_metadata: Testing metadata for the module
        :param pulumi.Input[_builtins.int] updated: Timestamp when the module was last modified
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: Versions of the module
        """
        if account is not None:
            pulumi.set(__self__, "account", account)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_tag_style is not None:
            pulumi.set(__self__, "git_tag_style", git_tag_style)
        if module_error is not None:
            pulumi.set(__self__, "module_error", module_error)
        if module_id is not None:
            pulumi.set(__self__, "module_id", module_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org is not None:
            pulumi.set(__self__, "org", org)
        if pipelines is not None:
            pulumi.set(__self__, "pipelines", pipelines)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if provider_connector is not None:
            pulumi.set(__self__, "provider_connector", provider_connector)
        if provisioner_type is not None:
            pulumi.set(__self__, "provisioner_type", provisioner_type)
        if provisioner_version is not None:
            pulumi.set(__self__, "provisioner_version", provisioner_version)
        if release_pipeline is not None:
            pulumi.set(__self__, "release_pipeline", release_pipeline)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if repository_branch is not None:
            pulumi.set(__self__, "repository_branch", repository_branch)
        if repository_commit is not None:
            pulumi.set(__self__, "repository_commit", repository_commit)
        if repository_connector is not None:
            pulumi.set(__self__, "repository_connector", repository_connector)
        if repository_path is not None:
            pulumi.set(__self__, "repository_path", repository_path)
        if repository_url is not None:
            pulumi.set(__self__, "repository_url", repository_url)
        if synced is not None:
            pulumi.set(__self__, "synced", synced)
        if system is not None:
            pulumi.set(__self__, "system", system)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if testing_enabled is not None:
            pulumi.set(__self__, "testing_enabled", testing_enabled)
        if testing_metadata is not None:
            pulumi.set(__self__, "testing_metadata", testing_metadata)
        if updated is not None:
            pulumi.set(__self__, "updated", updated)
        if versions is not None:
            pulumi.set(__self__, "versions", versions)

    @_builtins.property
    @pulumi.getter
    def account(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account that owns the module
        """
        return pulumi.get(self, "account")

    @account.setter
    def account(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was created
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the module
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitTagStyle")
    def git_tag_style(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git Tag Style
        """
        return pulumi.get(self, "git_tag_style")

    @git_tag_style.setter
    def git_tag_style(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_tag_style", value)

    @_builtins.property
    @pulumi.getter(name="moduleError")
    def module_error(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Error while retrieving the module
        """
        return pulumi.get(self, "module_error")

    @module_error.setter
    def module_error(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "module_error", value)

    @_builtins.property
    @pulumi.getter(name="moduleId")
    def module_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the module to enable testing for
        """
        return pulumi.get(self, "module_id")

    @module_id.setter
    def module_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "module_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the module
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def org(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization identifier
        """
        return pulumi.get(self, "org")

    @org.setter
    def org(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org", value)

    @_builtins.property
    @pulumi.getter
    def pipelines(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of pipeline IDs to create webhooks for triggering test executions
        """
        return pulumi.get(self, "pipelines")

    @pipelines.setter
    def pipelines(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "pipelines", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project identifier
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider connector for testing purposes
        """
        return pulumi.get(self, "provider_connector")

    @provider_connector.setter
    def provider_connector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_connector", value)

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "provisioner_type")

    @provisioner_type.setter
    def provisioner_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provisioner_type", value)

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provisioner version for testing purposes
        """
        return pulumi.get(self, "provisioner_version")

    @provisioner_version.setter
    def provisioner_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provisioner_version", value)

    @_builtins.property
    @pulumi.getter(name="releasePipeline")
    def release_pipeline(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Pipeline ID to create webhooks for releases
        """
        return pulumi.get(self, "release_pipeline")

    @release_pipeline.setter
    def release_pipeline(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "release_pipeline", value)

    @_builtins.property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        For account connectors, the repository where the module is stored
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository", value)

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository Branch in which the module should be accessed
        """
        return pulumi.get(self, "repository_branch")

    @repository_branch.setter
    def repository_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_branch", value)

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository Commit in which the module should be accessed
        """
        return pulumi.get(self, "repository_commit")

    @repository_commit.setter
    def repository_commit(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_commit", value)

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository Connector is the reference to the connector for the repository
        """
        return pulumi.get(self, "repository_connector")

    @repository_connector.setter
    def repository_connector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_connector", value)

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repository Path is the path in which the module resides
        """
        return pulumi.get(self, "repository_path")

    @repository_path.setter
    def repository_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_path", value)

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL where the module is stored
        """
        return pulumi.get(self, "repository_url")

    @repository_url.setter
    def repository_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_url", value)

    @_builtins.property
    @pulumi.getter
    def synced(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was last synced
        """
        return pulumi.get(self, "synced")

    @synced.setter
    def synced(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "synced", value)

    @_builtins.property
    @pulumi.getter
    def system(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider of the module
        """
        return pulumi.get(self, "system")

    @system.setter
    def system(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "system", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Tags associated with the module
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="testingEnabled")
    def testing_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether testing is enabled for the module
        """
        return pulumi.get(self, "testing_enabled")

    @testing_enabled.setter
    def testing_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "testing_enabled", value)

    @_builtins.property
    @pulumi.getter(name="testingMetadata")
    def testing_metadata(self) -> Optional[pulumi.Input['InfraModuleTestingTestingMetadataArgs']]:
        """
        Testing metadata for the module
        """
        return pulumi.get(self, "testing_metadata")

    @testing_metadata.setter
    def testing_metadata(self, value: Optional[pulumi.Input['InfraModuleTestingTestingMetadataArgs']]):
        pulumi.set(self, "testing_metadata", value)

    @_builtins.property
    @pulumi.getter
    def updated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was last modified
        """
        return pulumi.get(self, "updated")

    @updated.setter
    def updated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated", value)

    @_builtins.property
    @pulumi.getter
    def versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Versions of the module
        """
        return pulumi.get(self, "versions")

    @versions.setter
    def versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "versions", value)


@pulumi.type_token("harness:platform/infraModuleTesting:InfraModuleTesting")
class InfraModuleTesting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 module_id: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 pipelines: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
                 release_pipeline: Optional[pulumi.Input[_builtins.str]] = None,
                 testing_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 testing_metadata: Optional[pulumi.Input[Union['InfraModuleTestingTestingMetadataArgs', 'InfraModuleTestingTestingMetadataArgsDict']]] = None,
                 updated: Optional[pulumi.Input[_builtins.int]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.InfraModule("example",
            module_id=1234,
            org="default",
            project="project",
            provider_connector="account.connector",
            provisioner_type="tofu",
            provisioner_version="1.9.4",
            pipelines=[
                "pipelinea",
                "pipelineb",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import harness:platform/infraModuleTesting:InfraModuleTesting example <module_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] module_id: Identifier of the module to enable testing for
        :param pulumi.Input[_builtins.str] org: Organization identifier
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] pipelines: List of pipeline IDs to create webhooks for triggering test executions
        :param pulumi.Input[_builtins.str] project: Project identifier
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector for testing purposes
        :param pulumi.Input[_builtins.str] provisioner_version: Provisioner version for testing purposes
        :param pulumi.Input[_builtins.str] release_pipeline: Pipeline ID to create webhooks for releases
        :param pulumi.Input[_builtins.bool] testing_enabled: Whether testing is enabled for the module
        :param pulumi.Input[Union['InfraModuleTestingTestingMetadataArgs', 'InfraModuleTestingTestingMetadataArgsDict']] testing_metadata: Testing metadata for the module
        :param pulumi.Input[_builtins.int] updated: Timestamp when the module was last modified
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: Versions of the module
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InfraModuleTestingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.InfraModule("example",
            module_id=1234,
            org="default",
            project="project",
            provider_connector="account.connector",
            provisioner_type="tofu",
            provisioner_version="1.9.4",
            pipelines=[
                "pipelinea",
                "pipelineb",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import harness:platform/infraModuleTesting:InfraModuleTesting example <module_id>
        ```

        :param str resource_name: The name of the resource.
        :param InfraModuleTestingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InfraModuleTestingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 module_id: Optional[pulumi.Input[_builtins.str]] = None,
                 org: Optional[pulumi.Input[_builtins.str]] = None,
                 pipelines: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
                 provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
                 release_pipeline: Optional[pulumi.Input[_builtins.str]] = None,
                 testing_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 testing_metadata: Optional[pulumi.Input[Union['InfraModuleTestingTestingMetadataArgs', 'InfraModuleTestingTestingMetadataArgsDict']]] = None,
                 updated: Optional[pulumi.Input[_builtins.int]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InfraModuleTestingArgs.__new__(InfraModuleTestingArgs)

            if module_id is None and not opts.urn:
                raise TypeError("Missing required property 'module_id'")
            __props__.__dict__["module_id"] = module_id
            if org is None and not opts.urn:
                raise TypeError("Missing required property 'org'")
            __props__.__dict__["org"] = org
            if pipelines is None and not opts.urn:
                raise TypeError("Missing required property 'pipelines'")
            __props__.__dict__["pipelines"] = pipelines
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if provider_connector is None and not opts.urn:
                raise TypeError("Missing required property 'provider_connector'")
            __props__.__dict__["provider_connector"] = provider_connector
            if provisioner_type is None and not opts.urn:
                raise TypeError("Missing required property 'provisioner_type'")
            __props__.__dict__["provisioner_type"] = provisioner_type
            if provisioner_version is None and not opts.urn:
                raise TypeError("Missing required property 'provisioner_version'")
            __props__.__dict__["provisioner_version"] = provisioner_version
            __props__.__dict__["release_pipeline"] = release_pipeline
            __props__.__dict__["testing_enabled"] = testing_enabled
            __props__.__dict__["testing_metadata"] = testing_metadata
            __props__.__dict__["updated"] = updated
            __props__.__dict__["versions"] = versions
            __props__.__dict__["account"] = None
            __props__.__dict__["created"] = None
            __props__.__dict__["description"] = None
            __props__.__dict__["git_tag_style"] = None
            __props__.__dict__["module_error"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["repository"] = None
            __props__.__dict__["repository_branch"] = None
            __props__.__dict__["repository_commit"] = None
            __props__.__dict__["repository_connector"] = None
            __props__.__dict__["repository_path"] = None
            __props__.__dict__["repository_url"] = None
            __props__.__dict__["synced"] = None
            __props__.__dict__["system"] = None
            __props__.__dict__["tags"] = None
        super(InfraModuleTesting, __self__).__init__(
            'harness:platform/infraModuleTesting:InfraModuleTesting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account: Optional[pulumi.Input[_builtins.str]] = None,
            created: Optional[pulumi.Input[_builtins.int]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            git_tag_style: Optional[pulumi.Input[_builtins.str]] = None,
            module_error: Optional[pulumi.Input[_builtins.str]] = None,
            module_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org: Optional[pulumi.Input[_builtins.str]] = None,
            pipelines: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            provider_connector: Optional[pulumi.Input[_builtins.str]] = None,
            provisioner_type: Optional[pulumi.Input[_builtins.str]] = None,
            provisioner_version: Optional[pulumi.Input[_builtins.str]] = None,
            release_pipeline: Optional[pulumi.Input[_builtins.str]] = None,
            repository: Optional[pulumi.Input[_builtins.str]] = None,
            repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
            repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
            repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
            repository_path: Optional[pulumi.Input[_builtins.str]] = None,
            repository_url: Optional[pulumi.Input[_builtins.str]] = None,
            synced: Optional[pulumi.Input[_builtins.int]] = None,
            system: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[_builtins.str]] = None,
            testing_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            testing_metadata: Optional[pulumi.Input[Union['InfraModuleTestingTestingMetadataArgs', 'InfraModuleTestingTestingMetadataArgsDict']]] = None,
            updated: Optional[pulumi.Input[_builtins.int]] = None,
            versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'InfraModuleTesting':
        """
        Get an existing InfraModuleTesting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account: Account that owns the module
        :param pulumi.Input[_builtins.int] created: Timestamp when the module was created
        :param pulumi.Input[_builtins.str] description: Description of the module
        :param pulumi.Input[_builtins.str] git_tag_style: Git Tag Style
        :param pulumi.Input[_builtins.str] module_error: Error while retrieving the module
        :param pulumi.Input[_builtins.str] module_id: Identifier of the module to enable testing for
        :param pulumi.Input[_builtins.str] name: Name of the module
        :param pulumi.Input[_builtins.str] org: Organization identifier
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] pipelines: List of pipeline IDs to create webhooks for triggering test executions
        :param pulumi.Input[_builtins.str] project: Project identifier
        :param pulumi.Input[_builtins.str] provider_connector: Provider connector for testing purposes
        :param pulumi.Input[_builtins.str] provisioner_version: Provisioner version for testing purposes
        :param pulumi.Input[_builtins.str] release_pipeline: Pipeline ID to create webhooks for releases
        :param pulumi.Input[_builtins.str] repository: For account connectors, the repository where the module is stored
        :param pulumi.Input[_builtins.str] repository_branch: Repository Branch in which the module should be accessed
        :param pulumi.Input[_builtins.str] repository_commit: Repository Commit in which the module should be accessed
        :param pulumi.Input[_builtins.str] repository_connector: Repository Connector is the reference to the connector for the repository
        :param pulumi.Input[_builtins.str] repository_path: Repository Path is the path in which the module resides
        :param pulumi.Input[_builtins.str] repository_url: URL where the module is stored
        :param pulumi.Input[_builtins.int] synced: Timestamp when the module was last synced
        :param pulumi.Input[_builtins.str] system: Provider of the module
        :param pulumi.Input[_builtins.str] tags: Tags associated with the module
        :param pulumi.Input[_builtins.bool] testing_enabled: Whether testing is enabled for the module
        :param pulumi.Input[Union['InfraModuleTestingTestingMetadataArgs', 'InfraModuleTestingTestingMetadataArgsDict']] testing_metadata: Testing metadata for the module
        :param pulumi.Input[_builtins.int] updated: Timestamp when the module was last modified
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: Versions of the module
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InfraModuleTestingState.__new__(_InfraModuleTestingState)

        __props__.__dict__["account"] = account
        __props__.__dict__["created"] = created
        __props__.__dict__["description"] = description
        __props__.__dict__["git_tag_style"] = git_tag_style
        __props__.__dict__["module_error"] = module_error
        __props__.__dict__["module_id"] = module_id
        __props__.__dict__["name"] = name
        __props__.__dict__["org"] = org
        __props__.__dict__["pipelines"] = pipelines
        __props__.__dict__["project"] = project
        __props__.__dict__["provider_connector"] = provider_connector
        __props__.__dict__["provisioner_type"] = provisioner_type
        __props__.__dict__["provisioner_version"] = provisioner_version
        __props__.__dict__["release_pipeline"] = release_pipeline
        __props__.__dict__["repository"] = repository
        __props__.__dict__["repository_branch"] = repository_branch
        __props__.__dict__["repository_commit"] = repository_commit
        __props__.__dict__["repository_connector"] = repository_connector
        __props__.__dict__["repository_path"] = repository_path
        __props__.__dict__["repository_url"] = repository_url
        __props__.__dict__["synced"] = synced
        __props__.__dict__["system"] = system
        __props__.__dict__["tags"] = tags
        __props__.__dict__["testing_enabled"] = testing_enabled
        __props__.__dict__["testing_metadata"] = testing_metadata
        __props__.__dict__["updated"] = updated
        __props__.__dict__["versions"] = versions
        return InfraModuleTesting(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def account(self) -> pulumi.Output[_builtins.str]:
        """
        Account that owns the module
        """
        return pulumi.get(self, "account")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the module was created
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Description of the module
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitTagStyle")
    def git_tag_style(self) -> pulumi.Output[_builtins.str]:
        """
        Git Tag Style
        """
        return pulumi.get(self, "git_tag_style")

    @_builtins.property
    @pulumi.getter(name="moduleError")
    def module_error(self) -> pulumi.Output[_builtins.str]:
        """
        Error while retrieving the module
        """
        return pulumi.get(self, "module_error")

    @_builtins.property
    @pulumi.getter(name="moduleId")
    def module_id(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the module to enable testing for
        """
        return pulumi.get(self, "module_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the module
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def org(self) -> pulumi.Output[_builtins.str]:
        """
        Organization identifier
        """
        return pulumi.get(self, "org")

    @_builtins.property
    @pulumi.getter
    def pipelines(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of pipeline IDs to create webhooks for triggering test executions
        """
        return pulumi.get(self, "pipelines")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        Project identifier
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="providerConnector")
    def provider_connector(self) -> pulumi.Output[_builtins.str]:
        """
        Provider connector for testing purposes
        """
        return pulumi.get(self, "provider_connector")

    @_builtins.property
    @pulumi.getter(name="provisionerType")
    def provisioner_type(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "provisioner_type")

    @_builtins.property
    @pulumi.getter(name="provisionerVersion")
    def provisioner_version(self) -> pulumi.Output[_builtins.str]:
        """
        Provisioner version for testing purposes
        """
        return pulumi.get(self, "provisioner_version")

    @_builtins.property
    @pulumi.getter(name="releasePipeline")
    def release_pipeline(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Pipeline ID to create webhooks for releases
        """
        return pulumi.get(self, "release_pipeline")

    @_builtins.property
    @pulumi.getter
    def repository(self) -> pulumi.Output[_builtins.str]:
        """
        For account connectors, the repository where the module is stored
        """
        return pulumi.get(self, "repository")

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> pulumi.Output[_builtins.str]:
        """
        Repository Branch in which the module should be accessed
        """
        return pulumi.get(self, "repository_branch")

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> pulumi.Output[_builtins.str]:
        """
        Repository Commit in which the module should be accessed
        """
        return pulumi.get(self, "repository_commit")

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> pulumi.Output[_builtins.str]:
        """
        Repository Connector is the reference to the connector for the repository
        """
        return pulumi.get(self, "repository_connector")

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> pulumi.Output[_builtins.str]:
        """
        Repository Path is the path in which the module resides
        """
        return pulumi.get(self, "repository_path")

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL where the module is stored
        """
        return pulumi.get(self, "repository_url")

    @_builtins.property
    @pulumi.getter
    def synced(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the module was last synced
        """
        return pulumi.get(self, "synced")

    @_builtins.property
    @pulumi.getter
    def system(self) -> pulumi.Output[_builtins.str]:
        """
        Provider of the module
        """
        return pulumi.get(self, "system")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[_builtins.str]:
        """
        Tags associated with the module
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="testingEnabled")
    def testing_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether testing is enabled for the module
        """
        return pulumi.get(self, "testing_enabled")

    @_builtins.property
    @pulumi.getter(name="testingMetadata")
    def testing_metadata(self) -> pulumi.Output['outputs.InfraModuleTestingTestingMetadata']:
        """
        Testing metadata for the module
        """
        return pulumi.get(self, "testing_metadata")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the module was last modified
        """
        return pulumi.get(self, "updated")

    @_builtins.property
    @pulumi.getter
    def versions(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Versions of the module
        """
        return pulumi.get(self, "versions")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDelegateIdsResult',
    'AwaitableGetDelegateIdsResult',
    'get_delegate_ids',
    'get_delegate_ids_output',
]

@pulumi.output_type
class GetDelegateIdsResult:
    """
    A collection of values returned by getDelegateIds.
    """
    def __init__(__self__, delegate_ids=None, id=None, name=None, status=None, type=None):
        if delegate_ids and not isinstance(delegate_ids, list):
            raise TypeError("Expected argument 'delegate_ids' to be a list")
        pulumi.set(__self__, "delegate_ids", delegate_ids)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="delegateIds")
    def delegate_ids(self) -> Sequence[_builtins.str]:
        """
        A list of delegate ID's matching the specified search criteria.
        """
        return pulumi.get(self, "delegate_ids")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the delegate to query for.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the delegate to query for. Valid values are DELETED, ENABLED, WAITING*FOR*APPROVAL
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        """
        The type of the delegate to query for. Valid values are DOCKER, ECS, HELM*DELEGATE, KUBERNETES, SHELL*SCRIPT
        """
        return pulumi.get(self, "type")


class AwaitableGetDelegateIdsResult(GetDelegateIdsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDelegateIdsResult(
            delegate_ids=self.delegate_ids,
            id=self.id,
            name=self.name,
            status=self.status,
            type=self.type)


def get_delegate_ids(name: Optional[_builtins.str] = None,
                     status: Optional[_builtins.str] = None,
                     type: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDelegateIdsResult:
    """
    Use this data source to get a list of delegate ID's matching the specified search criteria.


    :param _builtins.str name: The name of the delegate to query for.
    :param _builtins.str status: The status of the delegate to query for. Valid values are DELETED, ENABLED, WAITING*FOR*APPROVAL
    :param _builtins.str type: The type of the delegate to query for. Valid values are DOCKER, ECS, HELM*DELEGATE, KUBERNETES, SHELL*SCRIPT
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['status'] = status
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:cloudprovider/getDelegateIds:getDelegateIds', __args__, opts=opts, typ=GetDelegateIdsResult).value

    return AwaitableGetDelegateIdsResult(
        delegate_ids=pulumi.get(__ret__, 'delegate_ids'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_delegate_ids_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDelegateIdsResult]:
    """
    Use this data source to get a list of delegate ID's matching the specified search criteria.


    :param _builtins.str name: The name of the delegate to query for.
    :param _builtins.str status: The status of the delegate to query for. Valid values are DELETED, ENABLED, WAITING*FOR*APPROVAL
    :param _builtins.str type: The type of the delegate to query for. Valid values are DOCKER, ECS, HELM*DELEGATE, KUBERNETES, SHELL*SCRIPT
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['status'] = status
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:cloudprovider/getDelegateIds:getDelegateIds', __args__, opts=opts, typ=GetDelegateIdsResult)
    return __ret__.apply(lambda __response__: GetDelegateIdsResult(
        delegate_ids=pulumi.get(__response__, 'delegate_ids'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AwsAssumeCrossAccountRole',
    'AwsUsageScope',
    'DatacenterUsageScope',
    'GcpUsageScope',
    'KubernetesAuthentication',
    'KubernetesAuthenticationOidc',
    'KubernetesAuthenticationServiceAccount',
    'KubernetesAuthenticationUsernamePassword',
    'KubernetesUsageScope',
]

@pulumi.output_type
class AwsAssumeCrossAccountRole(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "roleArn":
            suggest = "role_arn"
        elif key == "externalId":
            suggest = "external_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AwsAssumeCrossAccountRole. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AwsAssumeCrossAccountRole.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AwsAssumeCrossAccountRole.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 role_arn: _builtins.str,
                 external_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str role_arn: This is an IAM role in the target deployment AWS account.
        :param _builtins.str external_id: If the administrator of the account to which the role belongs provided you with an external ID, then enter that value.
        """
        pulumi.set(__self__, "role_arn", role_arn)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)

    @_builtins.property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> _builtins.str:
        """
        This is an IAM role in the target deployment AWS account.
        """
        return pulumi.get(self, "role_arn")

    @_builtins.property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[_builtins.str]:
        """
        If the administrator of the account to which the role belongs provided you with an external ID, then enter that value.
        """
        return pulumi.get(self, "external_id")


@pulumi.output_type
class AwsUsageScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "applicationId":
            suggest = "application_id"
        elif key == "environmentFilterType":
            suggest = "environment_filter_type"
        elif key == "environmentId":
            suggest = "environment_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AwsUsageScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AwsUsageScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AwsUsageScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 application_id: Optional[_builtins.str] = None,
                 environment_filter_type: Optional[_builtins.str] = None,
                 environment_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str application_id: Id of the application to scope to. If empty then this scope applies to all applications.
        :param _builtins.str environment_filter_type: Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        :param _builtins.str environment_id: Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if environment_filter_type is not None:
            pulumi.set(__self__, "environment_filter_type", environment_filter_type)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[_builtins.str]:
        """
        Id of the application to scope to. If empty then this scope applies to all applications.
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="environmentFilterType")
    def environment_filter_type(self) -> Optional[_builtins.str]:
        """
        Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        """
        return pulumi.get(self, "environment_filter_type")

    @_builtins.property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[_builtins.str]:
        """
        Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        return pulumi.get(self, "environment_id")


@pulumi.output_type
class DatacenterUsageScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "applicationId":
            suggest = "application_id"
        elif key == "environmentFilterType":
            suggest = "environment_filter_type"
        elif key == "environmentId":
            suggest = "environment_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DatacenterUsageScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DatacenterUsageScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DatacenterUsageScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 application_id: Optional[_builtins.str] = None,
                 environment_filter_type: Optional[_builtins.str] = None,
                 environment_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str application_id: Id of the application to scope to. If empty then this scope applies to all applications.
        :param _builtins.str environment_filter_type: Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        :param _builtins.str environment_id: Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if environment_filter_type is not None:
            pulumi.set(__self__, "environment_filter_type", environment_filter_type)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[_builtins.str]:
        """
        Id of the application to scope to. If empty then this scope applies to all applications.
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="environmentFilterType")
    def environment_filter_type(self) -> Optional[_builtins.str]:
        """
        Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        """
        return pulumi.get(self, "environment_filter_type")

    @_builtins.property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[_builtins.str]:
        """
        Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        return pulumi.get(self, "environment_id")


@pulumi.output_type
class GcpUsageScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "applicationId":
            suggest = "application_id"
        elif key == "environmentFilterType":
            suggest = "environment_filter_type"
        elif key == "environmentId":
            suggest = "environment_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in GcpUsageScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        GcpUsageScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        GcpUsageScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 application_id: Optional[_builtins.str] = None,
                 environment_filter_type: Optional[_builtins.str] = None,
                 environment_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str application_id: Id of the application to scope to. If empty then this scope applies to all applications.
        :param _builtins.str environment_filter_type: Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        :param _builtins.str environment_id: Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if environment_filter_type is not None:
            pulumi.set(__self__, "environment_filter_type", environment_filter_type)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[_builtins.str]:
        """
        Id of the application to scope to. If empty then this scope applies to all applications.
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="environmentFilterType")
    def environment_filter_type(self) -> Optional[_builtins.str]:
        """
        Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        """
        return pulumi.get(self, "environment_filter_type")

    @_builtins.property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[_builtins.str]:
        """
        Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        return pulumi.get(self, "environment_id")


@pulumi.output_type
class KubernetesAuthentication(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "delegateSelectors":
            suggest = "delegate_selectors"
        elif key == "serviceAccount":
            suggest = "service_account"
        elif key == "usernamePassword":
            suggest = "username_password"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KubernetesAuthentication. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KubernetesAuthentication.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KubernetesAuthentication.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 delegate_selectors: Optional[Sequence[_builtins.str]] = None,
                 oidc: Optional['outputs.KubernetesAuthenticationOidc'] = None,
                 service_account: Optional['outputs.KubernetesAuthenticationServiceAccount'] = None,
                 username_password: Optional['outputs.KubernetesAuthenticationUsernamePassword'] = None):
        """
        :param Sequence[_builtins.str] delegate_selectors: Delegate selectors to inherit the GCP credentials from.
        :param 'KubernetesAuthenticationOidcArgs' oidc: Service account configuration for connecting to the Kubernetes cluster
        :param 'KubernetesAuthenticationServiceAccountArgs' service_account: Username and password for authentication to the cluster
        :param 'KubernetesAuthenticationUsernamePasswordArgs' username_password: Username and password for authentication to the cluster
        """
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if oidc is not None:
            pulumi.set(__self__, "oidc", oidc)
        if service_account is not None:
            pulumi.set(__self__, "service_account", service_account)
        if username_password is not None:
            pulumi.set(__self__, "username_password", username_password)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[Sequence[_builtins.str]]:
        """
        Delegate selectors to inherit the GCP credentials from.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def oidc(self) -> Optional['outputs.KubernetesAuthenticationOidc']:
        """
        Service account configuration for connecting to the Kubernetes cluster
        """
        return pulumi.get(self, "oidc")

    @_builtins.property
    @pulumi.getter(name="serviceAccount")
    def service_account(self) -> Optional['outputs.KubernetesAuthenticationServiceAccount']:
        """
        Username and password for authentication to the cluster
        """
        return pulumi.get(self, "service_account")

    @_builtins.property
    @pulumi.getter(name="usernamePassword")
    def username_password(self) -> Optional['outputs.KubernetesAuthenticationUsernamePassword']:
        """
        Username and password for authentication to the cluster
        """
        return pulumi.get(self, "username_password")


@pulumi.output_type
class KubernetesAuthenticationOidc(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "clientIdSecretName":
            suggest = "client_id_secret_name"
        elif key == "identityProviderUrl":
            suggest = "identity_provider_url"
        elif key == "masterUrl":
            suggest = "master_url"
        elif key == "passwordSecretName":
            suggest = "password_secret_name"
        elif key == "clientSecretSecretName":
            suggest = "client_secret_secret_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KubernetesAuthenticationOidc. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KubernetesAuthenticationOidc.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KubernetesAuthenticationOidc.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 client_id_secret_name: _builtins.str,
                 identity_provider_url: _builtins.str,
                 master_url: _builtins.str,
                 password_secret_name: _builtins.str,
                 username: _builtins.str,
                 client_secret_secret_name: Optional[_builtins.str] = None,
                 scopes: Optional[Sequence[_builtins.str]] = None):
        """
        :param _builtins.str client_id_secret_name: Name of the Harness secret containing the client ID for the cluster.
        :param _builtins.str identity_provider_url: URL of the identity provider to use.
        :param _builtins.str master_url: URL of the Kubernetes master to connect to.
        :param _builtins.str password_secret_name: Name of the Harness secret containing the password for the cluster.
        :param _builtins.str username: Username for authentication to the cluster. This can be the username itself or the ID of a harness secret.
        :param _builtins.str client_secret_secret_name: Name of the Harness secret containing the client secret for the cluster.
        :param Sequence[_builtins.str] scopes: Scopes to request from the identity provider.
        """
        pulumi.set(__self__, "client_id_secret_name", client_id_secret_name)
        pulumi.set(__self__, "identity_provider_url", identity_provider_url)
        pulumi.set(__self__, "master_url", master_url)
        pulumi.set(__self__, "password_secret_name", password_secret_name)
        pulumi.set(__self__, "username", username)
        if client_secret_secret_name is not None:
            pulumi.set(__self__, "client_secret_secret_name", client_secret_secret_name)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)

    @_builtins.property
    @pulumi.getter(name="clientIdSecretName")
    def client_id_secret_name(self) -> _builtins.str:
        """
        Name of the Harness secret containing the client ID for the cluster.
        """
        return pulumi.get(self, "client_id_secret_name")

    @_builtins.property
    @pulumi.getter(name="identityProviderUrl")
    def identity_provider_url(self) -> _builtins.str:
        """
        URL of the identity provider to use.
        """
        return pulumi.get(self, "identity_provider_url")

    @_builtins.property
    @pulumi.getter(name="masterUrl")
    def master_url(self) -> _builtins.str:
        """
        URL of the Kubernetes master to connect to.
        """
        return pulumi.get(self, "master_url")

    @_builtins.property
    @pulumi.getter(name="passwordSecretName")
    def password_secret_name(self) -> _builtins.str:
        """
        Name of the Harness secret containing the password for the cluster.
        """
        return pulumi.get(self, "password_secret_name")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        Username for authentication to the cluster. This can be the username itself or the ID of a harness secret.
        """
        return pulumi.get(self, "username")

    @_builtins.property
    @pulumi.getter(name="clientSecretSecretName")
    def client_secret_secret_name(self) -> Optional[_builtins.str]:
        """
        Name of the Harness secret containing the client secret for the cluster.
        """
        return pulumi.get(self, "client_secret_secret_name")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[Sequence[_builtins.str]]:
        """
        Scopes to request from the identity provider.
        """
        return pulumi.get(self, "scopes")


@pulumi.output_type
class KubernetesAuthenticationServiceAccount(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "masterUrl":
            suggest = "master_url"
        elif key == "serviceAccountTokenSecretName":
            suggest = "service_account_token_secret_name"
        elif key == "caCertificateSecretName":
            suggest = "ca_certificate_secret_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KubernetesAuthenticationServiceAccount. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KubernetesAuthenticationServiceAccount.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KubernetesAuthenticationServiceAccount.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 master_url: _builtins.str,
                 service_account_token_secret_name: _builtins.str,
                 ca_certificate_secret_name: Optional[_builtins.str] = None):
        """
        :param _builtins.str master_url: URL of the Kubernetes master to connect to.
        :param _builtins.str service_account_token_secret_name: Name of the Harness secret containing the service account token for the cluster.
        :param _builtins.str ca_certificate_secret_name: Name of the Harness secret containing the CA certificate for the cluster.
        """
        pulumi.set(__self__, "master_url", master_url)
        pulumi.set(__self__, "service_account_token_secret_name", service_account_token_secret_name)
        if ca_certificate_secret_name is not None:
            pulumi.set(__self__, "ca_certificate_secret_name", ca_certificate_secret_name)

    @_builtins.property
    @pulumi.getter(name="masterUrl")
    def master_url(self) -> _builtins.str:
        """
        URL of the Kubernetes master to connect to.
        """
        return pulumi.get(self, "master_url")

    @_builtins.property
    @pulumi.getter(name="serviceAccountTokenSecretName")
    def service_account_token_secret_name(self) -> _builtins.str:
        """
        Name of the Harness secret containing the service account token for the cluster.
        """
        return pulumi.get(self, "service_account_token_secret_name")

    @_builtins.property
    @pulumi.getter(name="caCertificateSecretName")
    def ca_certificate_secret_name(self) -> Optional[_builtins.str]:
        """
        Name of the Harness secret containing the CA certificate for the cluster.
        """
        return pulumi.get(self, "ca_certificate_secret_name")


@pulumi.output_type
class KubernetesAuthenticationUsernamePassword(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "masterUrl":
            suggest = "master_url"
        elif key == "passwordSecretName":
            suggest = "password_secret_name"
        elif key == "usernameSecretName":
            suggest = "username_secret_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KubernetesAuthenticationUsernamePassword. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KubernetesAuthenticationUsernamePassword.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KubernetesAuthenticationUsernamePassword.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 master_url: _builtins.str,
                 password_secret_name: _builtins.str,
                 username: Optional[_builtins.str] = None,
                 username_secret_name: Optional[_builtins.str] = None):
        """
        :param _builtins.str master_url: URL of the Kubernetes master to connect to.
        :param _builtins.str password_secret_name: Name of the Harness secret containing the password for the cluster.
        :param _builtins.str username: Username for authentication to the cluster
        :param _builtins.str username_secret_name: Name of the Harness secret containing the username for authentication to the cluster
        """
        pulumi.set(__self__, "master_url", master_url)
        pulumi.set(__self__, "password_secret_name", password_secret_name)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if username_secret_name is not None:
            pulumi.set(__self__, "username_secret_name", username_secret_name)

    @_builtins.property
    @pulumi.getter(name="masterUrl")
    def master_url(self) -> _builtins.str:
        """
        URL of the Kubernetes master to connect to.
        """
        return pulumi.get(self, "master_url")

    @_builtins.property
    @pulumi.getter(name="passwordSecretName")
    def password_secret_name(self) -> _builtins.str:
        """
        Name of the Harness secret containing the password for the cluster.
        """
        return pulumi.get(self, "password_secret_name")

    @_builtins.property
    @pulumi.getter
    def username(self) -> Optional[_builtins.str]:
        """
        Username for authentication to the cluster
        """
        return pulumi.get(self, "username")

    @_builtins.property
    @pulumi.getter(name="usernameSecretName")
    def username_secret_name(self) -> Optional[_builtins.str]:
        """
        Name of the Harness secret containing the username for authentication to the cluster
        """
        return pulumi.get(self, "username_secret_name")


@pulumi.output_type
class KubernetesUsageScope(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "applicationId":
            suggest = "application_id"
        elif key == "environmentFilterType":
            suggest = "environment_filter_type"
        elif key == "environmentId":
            suggest = "environment_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KubernetesUsageScope. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KubernetesUsageScope.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KubernetesUsageScope.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 application_id: Optional[_builtins.str] = None,
                 environment_filter_type: Optional[_builtins.str] = None,
                 environment_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str application_id: Id of the application to scope to. If empty then this scope applies to all applications.
        :param _builtins.str environment_filter_type: Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        :param _builtins.str environment_id: Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if environment_filter_type is not None:
            pulumi.set(__self__, "environment_filter_type", environment_filter_type)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[_builtins.str]:
        """
        Id of the application to scope to. If empty then this scope applies to all applications.
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter(name="environmentFilterType")
    def environment_filter_type(self) -> Optional[_builtins.str]:
        """
        Type of environment filter applied. Cannot be used with `environment_id`. Valid options are NON*PRODUCTION*ENVIRONMENTS, PRODUCTION_ENVIRONMENTS.
        """
        return pulumi.get(self, "environment_filter_type")

    @_builtins.property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[_builtins.str]:
        """
        Id of the id of the specific environment to scope to. Cannot be used with `environment_filter_type`.
        """
        return pulumi.get(self, "environment_id")


